==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebGridKeydownEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridKeydownEventArgsDetailDescriptionMetadata } from "./WebGridKeydownEventArgsDetailDescriptionMetadata";
import { WebGridKeydownEventArgsDescription } from "./WebGridKeydownEventArgsDescription";
/**
 * @hidden
 */
export let WebGridKeydownEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridKeydownEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridKeydownEventArgsDescriptionMetadata.a == null) {
                WebGridKeydownEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridKeydownEventArgsDescriptionMetadata.c(WebGridKeydownEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebGridKeydownEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridKeydownEventArgsDescriptionMetadata.a);
            WebGridKeydownEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridKeydownEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebGridKeydownEventArgsDetail");
        }
        static d(a) {
            WebGridKeydownEventArgsDescriptionMetadata.b(a);
            a.aa("WebGridKeydownEventArgs", () => new WebGridKeydownEventArgsDescription());
            a.z("WebGridKeydownEventArgs", WebGridKeydownEventArgsDescriptionMetadata.a);
        }
    }
    WebGridKeydownEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridKeydownEventArgsDescriptionMetadata, 'WebGridKeydownEventArgsDescriptionMetadata');
    WebGridKeydownEventArgsDescriptionMetadata.a = null;
    return WebGridKeydownEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridKeydownEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridKeydownEventArgsDetailDescriptionMetadata } from "./WebGridKeydownEventArgsDetailDescriptionMetadata";
import { WebGridKeydownEventArgsDescription } from "./WebGridKeydownEventArgsDescription";
/**
 * @hidden
 */
export let WebGridKeydownEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridKeydownEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridKeydownEventArgsDescriptionMetadata.a == null) {
                WebGridKeydownEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridKeydownEventArgsDescriptionMetadata.c(WebGridKeydownEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebGridKeydownEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridKeydownEventArgsDescriptionMetadata.a);
            WebGridKeydownEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridKeydownEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebGridKeydownEventArgsDetail");
        }
        static d(a) {
            WebGridKeydownEventArgsDescriptionMetadata.b(a);
            a.ac("WebGridKeydownEventArgs", () => new WebGridKeydownEventArgsDescription());
            a.ab("WebGridKeydownEventArgs", WebGridKeydownEventArgsDescriptionMetadata.a);
        }
    }
    WebGridKeydownEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridKeydownEventArgsDescriptionMetadata, 'WebGridKeydownEventArgsDescriptionMetadata');
    WebGridKeydownEventArgsDescriptionMetadata.a = null;
    return WebGridKeydownEventArgsDescriptionMetadata;
})();
